/// <reference types="koa-bodyparser" />
/// <reference types="node" />
import 'reflect-metadata';
import * as Koa from 'koa';
import { Server as SocketIO } from 'socket.io';
import * as stoppable from 'stoppable';
import { TConfig } from '../types';
import { PowerManager, RedisClient, WorkerRunner } from 'redis-smq-common';
import { ICompatibleLogger } from 'redis-smq-common/dist/types';
export declare class MonitorServer {
    protected static instance: MonitorServer | null;
    protected config: TConfig;
    protected powerManager: PowerManager;
    protected logger: ICompatibleLogger;
    protected instanceId: string;
    protected workerRunner: WorkerRunner | null;
    protected application: {
        app: Koa;
        socketIO: SocketIO;
        httpServer: ReturnType<typeof stoppable>;
    } | null;
    protected redisClient: RedisClient | null;
    protected subscribeClient: RedisClient | null;
    private constructor();
    protected getRequiredProperty<K extends keyof MonitorServer>(key: K): MonitorServer[K];
    protected getApplication(): {
        app: Koa<Koa.DefaultState, Koa.DefaultContext>;
        socketIO: SocketIO<import("socket.io/dist/typed-events").DefaultEventsMap, import("socket.io/dist/typed-events").DefaultEventsMap, import("socket.io/dist/typed-events").DefaultEventsMap>;
        httpServer: (import("http").Server | import("https").Server) & stoppable.WithStop;
    };
    protected getSubscribeClient(): RedisClient;
    protected getRedisClient(): RedisClient;
    protected getWorkerRunner(): WorkerRunner;
    protected bootstrap(): Promise<{
        app: Koa<Koa.DefaultState, Koa.DefaultContext>;
        socketIO: SocketIO<import("socket.io/dist/typed-events").DefaultEventsMap, import("socket.io/dist/typed-events").DefaultEventsMap, import("socket.io/dist/typed-events").DefaultEventsMap>;
        httpServer: (import("http").Server | import("https").Server) & stoppable.WithStop;
    }>;
    protected subscribe(socketIO: SocketIO): Promise<void>;
    protected runWorkers(): Promise<void>;
    listen(): Promise<boolean>;
    quit(): Promise<boolean>;
    static createInstance(config?: TConfig): MonitorServer;
}
